template_ligand_search.py Command Help

Command: $SCHRODINGER/run -FROM psp template_ligand_search.py

usage: $SCHRODINGER/run -FROM psp template_ligand_search.py

Script to search the biolip database for homologous receptors.

Performs a BLAST search of the receptor sequence against entries in BioLip,
followed by a series of optional filters, returning a list of hits ranked
primarily by the BLAST E-value, along with relevant information.

Structures of hits are downloaded and aligned to the input receptor, if
one was provided. Using the '-skip_download' option skips the downloading.

In addition to filtering hits by sequence or structure properties, it is
possible to add an additional ligand similarity filter, by providing a
ligand structure (or SMILES string) and the '-min_tanimoto' option.

Example invocations:

* Search for ligand-bound homologs of a receptor provided as a structure
  $SCHRODINGER/run -FROM psp template_ligand_search.py -rec rec.mae

* Start the search from a PDB ID
  $SCHRODINGER/run -FROM psp template_ligand_search.py -pdb_id 3eml

* Search for homologs of a chain of the receptor
  $SCHRODINGER/run -FROM psp template_ligand_search.py -pdb_id 3sn6 -chain_id R

* Return top 10 hits
  $SCHRODINGER/run -FROM psp template_ligand_search.py -rec rec.mae -num_output_hits 10

* Do not download hit structures, produce only .csv file summary of hits
  $SCHRODINGER/run -FROM psp template_ligand_search.py -rec rec.mae -skip_download

* Return hits with receptor sequence identity > 30%
  $SCHRODINGER/run -FROM psp template_ligand_search.py -rec rec.mae -min_identity 30.0

* Return hits with ligand Tanimoto similarity > 0.3 to the ligand in lig.mae
  $SCHRODINGER/run -FROM psp template_ligand_search.py -rec rec.mae -lig lig.mae -min_tanimoto 0.3

* Exclude hits with specified UniProt IDs
  $SCHRODINGER/run -FROM psp template_ligand_search.py -rec rec.mae -exclude_uniprot UNP101010 UNP101011

* Return only hits with specified UniProt IDs
  $SCHRODINGER/run -FROM psp template_ligand_search.py -rec rec.mae -filter_by_uniprot UNP101010

options:
  -h, --help            show this help message and exit
  -jobname JOBNAME, -JOBNAME JOBNAME, -j JOBNAME
                        Optional name for template search job.

Receptor Options:
  -rec RECEPTOR, -receptor RECEPTOR
                        Input structure of the query receptor.
  -fasta FASTA          File containing the receptor sequence to query, in
                        FASTA format.
  -pdb_id PDB_ID        PDB ID of the receptor to query. To specify a
                        particular chain, use the -chain_id option
  -chain_id CHAIN_ID    Chain to extract from the query receptor structure.
                        This option is required when the input structure or
                        input PDB ID have more than one chain.

Ligand Options:
  -lig LIG              Ligand structure to use when filtering hits.
  -lig_smiles LIG_SMILES
                        Ligand SMILES string to use when filtering hits.
  -lig_asl LIG_ASL      ASL to specify ligand molecule in the receptor
                        structure.
  -min_tanimoto MIN_TANIMOTO
                        Minimum Tanimoto similarity value of ligands to input
                        ligand. Hits with a similarity value below this
                        threshold will be ignored.
  -max_tanimoto MAX_TANIMOTO
                        Highest Tanimoto similarity value of ligands to input
                        ligand. Hits with a similarity value above this
                        threshold will be ignored.

Sequence Search Options:
  -max_blast_homologs MAX_BLAST_HOMOLOGS
                        Maximum number of hits to return from BLAST search.
                        (default: 500).
  -min_identity MIN_IDENTITY
                        Minimum sequence identity (%) to query sequence
                        required for BLAST hits. Hits with sequence identity
                        below this threshold will be ignored. (default: 25.0)
  -max_identity MAX_IDENTITY
                        Highest sequence identity (%) to query sequence
                        required for BLAST hits. Hits with sequence identity
                        above this threshold will be ignored. (default: None)
  -min_similarity MIN_SIMILARITY
                        Minimum sequence similarity (%) to query sequence
                        required for BLAST hits. Hits with sequence similarity
                        below this threshold will be ignored.
  -max_similarity MAX_SIMILARITY
                        Highest sequence similarity (%) to query sequence
                        required for BLAST hits. Hits with sequence similarity
                        above this threshold will be ignored.
  -max_evalue MAX_EVALUE
                        Highest E-value allowed for BLAST hits. Hits with an
                        E-value above this threshold will be ignored.
                        (default: 10.0).

ID Filtering Options:
  -exclude_uniprot UNIPROT_EXCLUDE_SET [UNIPROT_EXCLUDE_SET ...]
                        Uniprot accession numbers to exclude from the results.
                        For example, '-exclude_uniprot A2BC19 P12345' excludes
                        all hits matching any of the two accession numbers.
                        Unless a specific isoform is provided (e.g. P12345-1),
                        all isoforms matching the parent accession will be
                        excluded.
  -exclude_uniprot_file UNIPROT_EXCLUDE_SET
                        File listing uniprot accession numbers to exclude from
                        the results. Should contain one accession number per
                        line. See help string of -exclude_uniprot for more
                        details.
  -filter_by_uniprot UNIPROT_FILTER_SET [UNIPROT_FILTER_SET ...]
                        Uniprot accession numbers to select from the results.
                        For example, '-filter_by_uniprot A2BC19 P12345'
                        returns only hits matching any of the two accession
                        numbers. Unless a specific isoform is provided (e.g.
                        P12345-1), all isoforms matching the parent accession
                        will be selected.
  -filter_by_uniprot_file UNIPROT_FILTER_SET
                        File listing uniprot accession numbers to select from
                        the results. Should contain one accession number per
                        line. See help string of -filter_by_uniprot for more
                        details.
  -exclude_taxid TAXID_EXCLUDE_SET [TAXID_EXCLUDE_SET ...]
                        NCBI taxonomy identifiers to exclude from the results.
                        For example, '-exclude_taxid 9606' excludes all human
                        hits.
  -exclude_taxid_file TAXID_EXCLUDE_SET
                        File listing NCBI taxonomy identifiers to exclude from
                        the results. Should contain one identifier per line.
                        See help string of -exclude_taxid for more details.
  -filter_by_taxid TAXID_FILTER_SET [TAXID_FILTER_SET ...]
                        NCBI taxonomy identifiers to select from the results.
                        For example, '-filter_by_taxid 9606' returns only
                        human hits.
  -filter_by_taxid_file TAXID_FILTER_SET
                        File listing NCBI taxonomy identifiers to select from
                        the results. Should contain one identifier per line.
                        See help string of -filter_by_taxid for more details.

wwPDB Search Filters:
  -from_date FROM_DATE  Earliest date (in ISO format, YYYY-MM-DD) to include
                        hits. Date is compared to the original structure
                        initial release date as recorded in the wwPDB. For
                        example, -from_date 2024-01-01 will only produce hits
                        released on and after Jan 1, 2024.
  -until_date UNTIL_DATE
                        Latest date (in ISO format, YYYY-MM-DD) to include
                        hits. Date is compared to the original structure
                        initial release date as recorded in the wwPDB. For
                        example, -until_date 2023-12-31 will only produce hits
                        released until Dec 31, 2023.
  -max_resolution MAX_RESOLUTION
                        Maximum structure resolution value to consider when
                        selecting hits. Structures with resolution above this
                        threshold will be ignored. Note that this option does
                        not affect NMR structures as these do not have a
                        defined resolution.
  -include_nmr          Include NMR structures in the results.

Output Options:
  -num_output_hits NUM_OUTPUT_HITS
                        Number of final hits to write to output .csv file.
                        Note that this is an upper limit - the actual search
                        might return less hits.
  -skip_download        Skip downloading annotated hit structures.

Job Control Options:
  -HOST <hostname>      Run job remotely on the indicated host entry.
  -WAIT                 Do not return a prompt until the job completes.
  -D, -DEBUG            Show details of Job Control operation.
  -NOJOBID              Run the job directly, without Job Control layer.

Standard Options:
  -NOLAUNCH             Set up subjob inputs, but don't run the jobs.